@@ -19,7 +19,6 @@ from configobj import ConfigObj, flatten_errors
 from validate import Validator
 import sys
 import os.path
-from ipaddress import ip_address
 from pkg_resources import resource_stream
 from gns3converter.adapters import PORT_TYPES
 from gns3converter.models import MODEL_TRANSFORM
@@ -74,7 +73,7 @@ class Converter():
         res = config.validate(vtor, preserve_errors=True)
         if res and self._debug:
             print('Validation Passed')
-        else:
+        elif not res:
             for entry in flatten_errors(config, res):
                 # each entry is a tuple
                 (section_list, key, error) = entry
@@ -93,18 +92,16 @@ class Converter():
         configspec.close()
         return config
 
-    @staticmethod
-    def process_topology(sections, old_top):
+    def process_topology(self, old_top):
         """
         Processes the sections returned by get_instances
 
-        :param list sections: list of sections as generated by
-                              :py:meth:`get_instances`
         :param ConfigObj old_top: old topology as processed by
                                   :py:meth:`read_topology`
         :returns: tuple of dicts containing hypervisors, devices and artwork
         :rtype: tuple
         """
+        sections = self.get_sections(old_top)
         topo = LegacyTopology(sections, old_top)
 
         for instance in sorted(sections):
@@ -127,25 +124,15 @@ class Converter():
         return topo.devices, topo.conf, topo.artwork
 
     @staticmethod
-    def get_instances(config):
+    def get_sections(config):
         """
         Get a list of Hypervisor instances
 
         :param ConfigObj config: Configuration from :py:meth:`read_topology`
-        :return: hypervisor instances
+        :return: configuration sections
         :rtype: list
         """
-        instances = []
-        for item in sorted(config):
-            if ':' in item:
-                delim_pos = item.index(':')
-                addr = item[0:delim_pos]
-                try:
-                    ip_address(addr)
-                    instances.append(item)
-                except ValueError:
-                    pass
-        return instances
+        return config.sections
 
     def generate_nodes(self, devices, hypervisors):
         """
